@@ -59,13 +59,13 @@ SettingsBase::SettingsBase( QWidget * parent )
     setWindowFlags( windowFlags() | Qt::WindowContextHelpButtonHint );
     // Initialise search
     searchText = new KLineEdit( this );
-    searchText->setClearButtonShown( true );
+    searchText->setClearButtonEnabled( true );
     searchText->setPlaceholderText( i18nc( "Search through a list of control modules", "Search" ) );
     searchText->setCompletionMode( KCompletion::CompletionPopup );
 
     spacerWidget = new QWidget( this );
     spacerWidget->setSizePolicy( QSizePolicy::MinimumExpanding, QSizePolicy::Maximum );
-    // Initalise the window so we don't flicker
+    // Initialise the window so we don't flicker
     initToolBar();
     // We can now launch the delayed loading safely
     QTimer::singleShot(0, this, &SettingsBase::initApplication);
@@ -404,7 +404,7 @@ void SettingsBase::changeToolBar( BaseMode::ToolBarItems toolbar )
     toolBar()->setVisible(toolbar != BaseMode::NoItems || (activeView && activeView->actionsList().count() > 0));
 }
 
-void SettingsBase::changeAboutMenu( const KAboutData * menuAbout, QAction * menuItem, QString fallback )
+void SettingsBase::changeAboutMenu( const KAboutData * menuAbout, QAction * menuItem, const QString &fallback )
 {
     if( !menuItem ) {
         return;
