@@ -72,7 +72,7 @@ ModuleView::ModuleView( QWidget * parent )
     d->mLayout = new QVBoxLayout(this);
     // Create the Page Widget
     d->mPageWidget = new KPageWidget(this);
-    d->mPageWidget->layout()->setMargin(0);
+    d->mPageWidget->layout()->setContentsMargins(0, 0, 0, 0);
     d->mLayout->addWidget(d->mPageWidget);
     // Create the dialog
     d->mButtons = new QDialogButtonBox( Qt::Horizontal, this );
@@ -129,11 +129,7 @@ const KAboutData * ModuleView::aboutData() const
     if( activeModule ) {
         aboutData = const_cast<KAboutData*>( activeModule->aboutData() );
     }
-    if ( aboutData ) {
-        aboutData->setProgramIconName( activeModule->moduleInfo().service()->icon() );
-        return aboutData;
-    }
-    return nullptr;
+    return aboutData;
 }
 
 void ModuleView::loadModule( const QModelIndex &menuItem )
@@ -217,7 +213,7 @@ void ModuleView::updatePageIconHeader( KPageWidgetItem * page, bool light )
         return; 
     }
 
-    page->setHeader( moduleInfo->comment() );
+    page->setHeader( moduleInfo->moduleName() );
     page->setIcon( QIcon::fromTheme( moduleInfo->icon() ) );
     //HACK: not much other ways to detect is a qml kcm
     if ( moduleProxy && moduleProxy->realModule()->inherits("KCModuleQml") ) {
@@ -228,7 +224,7 @@ void ModuleView::updatePageIconHeader( KPageWidgetItem * page, bool light )
     }
 
     if( moduleProxy && moduleProxy->realModule()->useRootOnlyMessage() ) {
-        page->setHeader( moduleInfo->comment() + QStringLiteral("<br><small>") + moduleProxy->realModule()->rootOnlyMessage() + QStringLiteral("</small>") );
+        page->setHeader( moduleInfo->moduleName() + QStringLiteral("<br><small>") + moduleProxy->realModule()->rootOnlyMessage() + QStringLiteral("</small>") );
         page->setIcon( KDE::icon( moduleInfo->icon(), QStringList() << QStringLiteral("dialog-warning") ) );
     }
 }
